package
module
Version:
v0.1.0
Opens a new window with list of versions in this module.
Published: May 6, 2022
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
Documentation
¶
type Clock interface {
Now() time.Time
}
Clock provides the sub set of methods in time.Time that this package provides.
Start creates a new Clock starting at t.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.